@@ -170,3 +170,8 @@ class TrainerWithTimer(Trainer):
         if self.tmr:
             return TimeLoaderWrapper(dl, self.tmr)
         return dl
+
+    def save_model(self, output_dir: Optional[str] = None, _internal_call: bool = False):
+        self.timer.start(timer.TimeType.SAVING_MODEL)
+        super().save_model(output_dir=output_dir, _internal_call=_internal_call)
+        self.timer.end(timer.TimeType.SAVING_MODEL)
